@@ -45,6 +45,7 @@
 #' @aliases Andromeda
 #' @seealso [`andromeda()`]
 #' @import RSQLite
+#' @importClassesFrom DBI DBIObject DBIConnection
 #' @export
 setClass("Andromeda", contains = "SQLiteConnection")
 
@@ -129,7 +130,8 @@ copyAndromeda <- function(andromeda) {
 .createAndromeda <- function() {
   tempFolder <- .getAndromedaTempFolder()
   andromeda <- RSQLite::dbConnect(RSQLite::SQLite(),
-                                  tempfile(tmpdir = tempFolder, fileext = ".sqlite"))
+                                  tempfile(tmpdir = tempFolder, fileext = ".sqlite"),
+                                  extended_types = TRUE)
   class(andromeda) <- "Andromeda"
   attr(class(andromeda),"package") <- "Andromeda"
   finalizer <- function(ptr) {
